
# q-expansion of newform 75.16.a.j, downloaded from the LMFDB on 07 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 75
weight = 16
poly_data = [-19672158033999, -70310137200, 3920349703, -1279200, -140297, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0], 1], [[-46766, -14, 1, 0, 0, 0], 1], [[1575300742593, 18077014855, -155293256, -1141080, 1151, 9], 35456], [[1670349840065, 15118566215, -157810632, -1105624, 1151, 9], 35456], [[-3333830460751, -46373480185, 340699224, 2901320, -2449, -23], 17728]]

hecke_ring_character_values = None
aps_data = [[39, -1, 0, 0, 0, 0], [-2187, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0], [-431710, 1644, -19, -1, 0, 0], [17914848, 591, -24, -6, 1, -5], [-18313848, 76151, -683, -15, -27, -9], [595512438, -4601343, 16090, -308, -153, 61], [-267048069, 9846007, 26642, -792, -207, 171], [-1092622002, 18636139, 46714, 40, -2499, 799], [21149323788, 32111203, 744036, 5046, -8675, -1505], [25294627048, -164093048, 3456073, -17797, 6516, 2268], [102687289156, 248401756, 7287738, -17834, 34236, -44460], [181888358712, -2172562817, 24237118, -229220, -38407, -21117], [-407496029451, -5936090405, -2234948, -50434, -241371, 12519], [-1394865182484, -6177042582, -23907970, -1388314, -28994, -24342], [-2761869310068, 7787856581, 99967378, 83740, 1020259, 84929], [1466021066742, -2679128648, -240219704, 10600, 1487272, 294968], [-1160059216554, 50335525979, -343363849, 1357999, -1988487, -405549], [-8914709954551, -166759767111, -400090696, 5019446, 2490039, 1391949], [17439174209262, 52223156723, 445195680, -17113206, -3934947, -8097], [29499619262016, -72416805300, -1637785370, -26643110, 4131036, -478764], [30919533163042, -505260059850, 1578537778, -4230710, 11439522, 2671254], [72637890517026, 248085582672, -199134144, -55746432, 4329840, 273072], [71918321978676, -215115213576, -3513563108, 126796996, -22687784, 8632424], [-168935684403197, -1518517568380, 791262924, 40474076, -37299060, -918972], [56747587635660, -2112379431421, -2574877946, 218733052, 44569013, -31549401], [482291629966, 1659270442768, -4546779762, 23000266, -78091848, -3939768], [-871527387459954, 4509268826699, 11547578012, 8418974, -87089163, -29584009], [1454490234901916, -2310565519601, -3987561081, 100329655, -180266427, 91606743], [259345380314508, 3226627575384, 42522426616, -439747304, 186111240, 8207416], [-2703309878830248, 900929189482, 112289611612, 1260735008, -60444666, 139745538], [4647744743247678, -2258610412425, 95727303724, -1636944170, -559526135, -13494925], [-4583360554124850, -1733811795422, 169778550216, 118804692, -303430690, -90540502], [6382539667793834, 3359084546628, -84477820302, 151084206, -58890636, 67287996], [13902302753963760, -46659879004604, -174164244702, -3179521122, -591405452, 330634588], [9894311723212218, 28786350769328, -180984768631, 3845814283, 1937531916, 65873412], [-15141194493038954, -93142594615835, 54306189897, -3392852975, 221621319, -304652115], [13746959850010447, 41483730507221, 131623319340, -3854827750, 3735621387, -2320268823], [-38719847595847494, -24436081283339, -473081913676, 6440544098, 1924070827, -444965703], [-17228279055047148, -17982096057413, -920852897652, -7685255970, -5777247643, 1600103063], [18101254607833950, 93304619572282, -50457055772, -4226388968, 1435719190, -3896703502], [22383150937511354, -107198691306577, 600335316285, -24913408327, -573695091, -1063963665], [2997438112702434, 263086519057787, 69804252354, 10756989696, 11625261645, -4909466001], [-70069017883202357, 523552083632924, -108910136286, -2577692242, -2988145764, -1350254700], [21531745780341204, 372402070439464, 1353097922062, 17819143258, -10181158752, 2298231424], [-41121109870845762, -603059671013866, -82992724003, -6646856357, 2641048182, -10467003438], [17039280708067355, -1313935473826997, -1167406427142, 6300889720, 14298754941, -2167440273], [-24946729879289342, 1789609424558052, 5454284038989, 42729913647, -39821273208, -687465576], [120187419748162362, 1203027771846177, -2053832357744, 46448301358, -27463036945, 16430537589], [-229939673190606416, -1003045880325845, 9814695592759, 90252968399, -22804409943, 12819269475], [-120066440019822444, 1009751038225633, 11470564506710, -999001024, 20697392407, -26004301491], [-321161026315439622, -866170186850361, -3685634616696, -267735787782, -77801817431, -14025128957], [-25070473863328893, -981412617133934, -971806224550, 97379276010, 71483868198, 26213185314], [-432036640720918032, 2536997441795082, 19166104784944, 52356093724, 7254103702, -7411027342], [783118600227421896, -483970760951298, 5383270396984, 279600355660, 33520796866, -16203685738], [-306581043809121426, 96141806420583, 1671777603712, -313025305022, 28150245737, -64051658397], [143402434280613648, -3183686893153161, -14516279737148, 36689339374, 219794739017, -28482568701], [-358631355467931258, 4538152048362076, 8390533633730, -42603660018, -108060768036, -13600622700], [531166685004939362, -3921935288073679, 17031871487267, 348076078375, 155438266131, 50079208113], [-231106998254856414, 9168931574566927, 12587354862538, -200295349952, 1046741625, -80977446941], [-382968945990211315, 5732667842933421, -2966036419246, 44936658620, 59809955931, -44208386343], [176378311878766080, 12203494979914570, -26024454803698, -353203592074, 139197877726, 223606268394], [-1226069558402535027, 15302162127235997, 32858932227466, -1162070002812, -497825496693, 73413519849], [-1678167460789587576, -2770386115365952, -78004329859698, 569323365258, -405103322552, 106821646360], [2454320966985231421, 4621742749424822, 29045210083260, -515040538360, -245413632582, -100720775394], [3084412746348339864, 12891408816361838, 2614182358332, 894340138008, -666669585790, 148924879670], [4848236890364761132, 6506075549474906, 90481566723460, 837297958296, 403217945910, 60503025330], [-2180376265542646995, 9573132248975748, 166777763852698, 2637361927942, -80224849836, -181958592132], [3905532353162942670, 808417796272504, -34200930301416, -2474359419528, -282009878552, 223031696920], [3364233214104807114, 34224235033596300, -62244434617456, -962796293416, 303940315764, 55701453564], [690818502288951918, 46989543185897269, -131494517431434, 1911321391320, 47413355075, -130070772271], [10756984310910137682, 12988012215805723, -150109887247116, -3243972178698, 503265217445, 289105934519], [-2846922823784086324, -6291339140118424, 26179595400149, -2382662517857, 434413948644, -570459030804], [3613721185069820166, -45851154058349533, 85113151329349, 2988238565097, 235408010553, -797009432301], [-506083282443400641, -60557972985711649, 111214182358316, -5503738982906, -1491523664607, 239348000187], [-409336645912519572, -21649297327727714, 276782832174540, 1303501600488, 265513025042, 813896836454], [676718487526587576, -52872815050368143, -365397017134294, 9454602867884, 1474576930903, 327866082717], [-6497600929794667806, 35029305480303703, -221773164420587, 3628754299313, 2328001018245, -940415329449], [-974868658013235936, -33992295338757499, 500294926162934, 604482213176, -46371819789, 857587136993], [-31130036838389692927, 12347256946679170, 514942891999560, 1866889095124, 590040247806, -667464003702], [402283451702967474, 52844155684594543, 66011622781224, 8960013576282, -2586960706655, -1525240732229], [18487510525620618744, 33458503763149760, 58071651379334, -685760556494, -312791916312, -1240973256456], [-8303255427809322066, 24319973150613361, 1128608758278842, -2101176692068, 6896598533527, 132371371485], [-46354689682538673621, -44142831144978168, -76477478108918, -10875900458162, -3062651862960, 82415820816], [-34893045036709728546, 135409276694258270, 854199881267567, -10657497699359, -1871637320538, 1577049958242], [-27123840591085722828, -196149644328555250, -571122529382944, 60589877444, 1888994736978, -3399821037850], [10636234934732050380, 159431111191024102, 487524687646500, 9520364850912, 4382151391722, 3837546927534], [10600268910099565584, -70691426029075626, 676241075872678, 18870431453830, -3825407352078, -2683881883098], [7350418359363574116, -291644630082939463, 448525219371162, -12354317802804, -11827591612529, 1936008851941], [-77129383243932019870, 60009586512628556, 1258004636550614, 13461100175530, 2911898894364, 677848015188], [37699944974897664696, 520853130070665845, -1825347742413024, 7725997547862, 419809820123, 3775103150201], [75522080248720648908, 173021920205107382, -591637798169002, -9662502116746, -13056719587566, -5177231029402], [-16062645682667633174, -597121302379724256, 451160893904919, 14171554706997, 7980078204324, 1930672853388], [53229242911156731888, -312896838636493068, -904386981141632, 14251948822456, -25492940127348, -5637744768284], [55949882203411437477, 108160404033530079, -65351587090720, 59786917672418, 7716280666833, 2330500048011], [28528779323518771542, -422116254170721065, -2891199614287320, -4692259679814, -15335603186151, -3722913097005], [81609260078238316176, 287721919091596412, -799141238763154, -59255370570670, 2773398897676, 8550391548900], [131529296789388301278, 504456457669426583, 947158803018630, 62229145600836, 33894830816577, -4072882519269], [-35925937517510508423, 246704615786149799, -1916870234148326, 61373889003936, -15343721711775, 328537727163], [265649195271483831466, -426472145212566289, 1151737851245257, 1954777273053, -6935678515683, 11697832266399], [-15221167785770830122, -210923822236862532, 992915150632618, 97073386847206, 12114719610012, 175351827060], [166692952597180493172, -506014472980809130, 3893131451891758, -21980395045346, 6665776721618, 12812764040838], [-91653903395940792576, 474878693824356335, 4207937737601504, -56618199613726, -7131114313983, -12385737578437], [202692810704794437726, 42537702476522863, -5454833384332338, -33415786325364, -18214241290231, 9882499173587], [-38517958434698987359, 1079783166501474189, -5266140970511616, 117883313408358, 9592744971267, -3192056424495], [225544044853811667037, 952535153903676676, -3271664651227728, -104969879089400, -27127704034692, -27501158675628], [71251008685796980506, -44079308340104621, 1956938255653264, 39972051365578, 13382524264029, 26383902081295], [-114454037670146406360, -433320768464806997, 2452363810468174, 5944769724628, -3447636646643, -21566923588609], [148885350902976735984, -517312135243988186, 93406210041576, 60541897346508, -86451150330662, 12026769392734], [259969181661437214191, 1039150765934336110, 3806895340420272, -29586953593484, -40600176812622, 16679407695174], [284609541498776909262, 1437208371083455222, 507221054474542, -7462588397314, -45435528323982, 8125255105542], [-59899982747290258188, 2006849557045380086, 978942305540014, -91586765788194, -5886379311822, 2687943337830], [75952042905200455644, 2918092546800901223, -710870847424954, -44338748877052, 5742166226097, -31089867295477], [-46195383322876624957, 378932644414806439, 5442707071981446, 116150664785380, -64304582749263, 40219738251435], [34044339120916244004, 3045040997224438738, -1834151774644459, -179103659739093, 24870089361114, -86254703802306], [851475608791998726240, 119426121621344546, -1308402906010224, -91993042702932, 139056759054526, -16007974737590], [-660971621708497184626, -459367261949160396, -10332118870450138, 234714115211690, 72053216890164, -8162249954436], [309357884550067189956, 1323260410383794184, 14081510235631160, -14211742988968, -6246133648616, -45404131361976], [-153387368394246919344, 137798360937836226, 8346634358658018, 15280975818690, -78064111431914, -4430373989678], [-283450482776840420634, -4678457676270460097, 27562472857626848, -110256712513246, 18639998770289, -19420545889301], [611399564485344758592, 4605817150845016350, 16960911982920206, 258037508563118, -117983140224246, -1256302567890], [-745228327960347332296, 5622361822532700704, -6533012428653646, -91073928077930, -75658866058728, -26453539622808], [-631858474211232900216, -2059794640179900549, -16063158776098492, 222900137465030, -24196883439547, 86709637089655], [-1618470452547625098972, 2237547777683531916, 9536556918448700, -238482633380356, 106323499096580, -52661221788788], [-922737708819654262716, 7157533791065680438, 14673708468259184, -672518232540, 95318483552874, 115261337984238], [879499074030494773680, -471850126302353597, -42725634707760676, -129179147423362, -185870284714083, -65582751693889], [327498142647244136448, -12234934753264649, -21874907124720529, 211990444154847, -45031687109955, 69280518319551], [270121201000093831014, -11136259933311578007, 17875966540000818, 14192716667988, -69962044221249, -20443465286571], [-1325794075717704815594, 2143216740537502512, -71664614404323927, 157605996597867, -42057715519476, 145960987134276], [1541894097130069669114, 2101138866949830036, 17333913604286568, -57687327718704, -99793160190324, -3706366110588], [1617037113683918266944, 7277765277522790372, -5885623630298428, -694114341411324, 187065444125772, -20777616463932], [-1081308320533533647316, -4344799261887303964, -21066405124679072, 715708777970872, -362651871878756, 113415568441940], [760750424136633920796, -5626513203075794446, 7541910322509656, 344912264629444, 193752050832270, -217578194824230], [1055532574277918007426, -7143906933325663337, 81844592489297179, -78023335345885, 323693107295085, -181290775947057], [1427644030253001962292, 11412386705547497080, -23446567910638104, -1243004746974648, 431106775971944, 98545701826808], [17583012012940035131, 15560881727147692958, 3646327546385508, -555714044530768, -345236295793230, 25631609163462], [2287528895422779662160, 4801853044458917047, -25222599162824394, 249625198591908, 691561519415681, -3081153015637], [-1753337027361517840917, 2342118792969105801, -34744974850179764, -81823052305454, 267733116236439, 51285300728301], [-2609480237197519858596, 10282732963639274258, 97105995979329332, 566083090277912, 247138969960702, 130771452255402], [-930607618339413450240, -3058549170220228717, -63292568576639742, 1338245936902080, -505731877405419, -180249306048201], [-1959542110467845245685, -6894486210740137903, -129067893756734450, -861371503432152, -187347510578169, 98181746474877], [-432547493577500692476, 6473505117153665290, -14926700577137010, -978691373492874, -508208042977762, 18431018726570], [-485999247446818979108, -3866677247190846398, -47610406620792333, 576452410857541, -637625095830990, -252588039403770], [-2553581651099518104438, -5294142423812698385, -48573063184987664, 1364039140296178, -592522228689535, 265718140419483], [-1046781906919277897624, 19933956716341702426, 34189474809285478, 599125810989566, 1028998832419566, 57148569958266], [1576646984611604667378, -7080687216075819959, -42428367035880366, -1079650346968812, 531662910899359, 216602384754709], [1548362373375649579160, 12414813426449771907, 198900504021467, 998919757635083, 1000255710328641, 33579062155179], [4321251898203665765508, -5719538201009728594, 100871160078355924, -770598604045184, 1063932463234594, 134985215131574], [-3011590891740030892608, 23171007903976729958, 68149118867076932, -943718545472960, -992690350822422, 623379581468334], [-2489734294487010021696, -22181876845719602066, -137596883287727428, 299512685578520, 1381184021784194, -44993076248906], [445309612291560181712, -46688007683521164645, -49584283077678493, 3898815390439667, 617913382575753, 66754046454723], [-2620507950497529030864, -35840083647911500022, 66917243927450100, -3132208552599096, -943662180106170, 5155938689826], [481515055359359689483, -1098291324694591611, 322126832891218746, 962847832867140, 13234481028963, -209781956352015], [2341935489675976053000, 10467322745550272994, -172794106412509642, 2562063971162942, 493113032140070, -132680693676542], [2556052317946286627492, -39469631422333986700, -23483897389834504, 181611967974976, -2534363824476564, 304258355544996], [-4951453876073647940628, -58664949812837109274, 23301346086040222, 1735810345935982, 1880361109698, -9496051759370], [-8008410803425876345416, 8394135361754297096, 338224590382946219, -1482679768601855, -169084527417684, -67645149918012], [-13434947391852253800714, 3575347670441839597, -132600170324034782, -5856767183620628, -141635730384805, -604423589648871], [-2468646548807044399147, 25775936832324412230, 275805104392231760, -955818065192668, -1525466928311334, 575573290880958], [-10176514090925201243328, -25636269858270522314, -171496257140668622, -2340225900492854, -481392346431838, -271295637433578], [7134511921089508957296, 16142871472395623069, -43554759790141916, 4965143016185362, -1626618413574877, 397653974655441], [10432223509603293520248, 43489901570094700156, 44620207738973112, -4240671138881232, 701540502167908, -1152540164979572], [-11318793837088284524426, 31128127752792090150, -80610484964274210, 2386581739770030, 2430160170038658, -1048696340745546], [-23621268646599193303770, 7334064099090624370, 79243836308935472, -997745690596084, 1619078695955758, -46742341945542], [8511181503029782080810, -31121848430328050790, -408487865861140472, -542291461896188, -1796171811817050, -199729206338654], [8360879541970681174236, -85201816316536164, 388707329554980680, -117581276288896, 324893713798340, 1462434784027660], [-10159492783964066941012, 41326161007274467418, -253065679981003971, -1743768098160493, -1764242174792142, 1663659885226374], [-29357187214821372932218, 46194657184817302852, -205214596137150640, -1597189960581144, 469929438970812, 1083306813443028], [-71871697520239464841, 42029573739482753438, 578307099775612434, 526011422639738, 2911824326238714, 1440315720267966], [23047116450455645433684, -29154698864476242712, 76251182670594538, 2969365323286798, 202654018161840, -1177731244185200], [5891067863920728681444, -147383728741962103163, -214849657905201264, 10956557823729990, -318955221995893, 919069130027465], [-7423554073278306463428, 110178198211853733891, -38279497472272051, 3284947671321089, -1074954934141767, -796048596497709], [1839444603968495786424, 17723784158772417588, 586342088861762966, 10993388585348282, -1080921853121548, -2015568085498820], [-5920634971357963350865, 45268555265208206006, -242405243495917792, 1093913132515636, -1794165835386582, 1307549374585902], [1614707677170948472842, 30575175099576574580, -226061710299984787, -14336296335693713, 2067334527227256, -875940234280344], [8060209295992389121416, -9050381705658387910, -1221255893406300436, -5443895095655536, 1278417144348342, -987404608232398], [-9735525482027440078319, 107485189879454318343, 210411215455318204, -4972126464272282, 2674318823073081, 643677506800515], [-48375176168534043180, 156484595659914439033, -342882609926653924, -5193030756948910, 3841909778657095, 1293017739712173], [6407475145904636376250, 80832518878126485858, -105075649585872807, 6076450126309239, 7362031234978170, -131812990892802], [-9842109255177886012536, 2943504569407639557, -1121005936182522763, 802497075783701, 1710521303834871, -701583765138819], [-12485421306156077747984, -46862007223730376330, -832523451635003625, 15384260346435081, -1143216211992786, -1547235232643430], [28174608151436194207932, -33660858970273695028, -306414599058752172, -3444160733342268, -3987112912823964, -697906172703060], [10682972513621725197846, 202444622011004999073, 281758636987590931, 1373870909325655, -3391866976559517, 828502775553825], [-3252966068717145488634, 26162116874172220416, -440470767776620624, -9163107153713680, 6065756047474944, -2841731964876448], [43724838055556413617852, 109452720583730155130, 548493490692067654, 13860312203891134, -6387429636141874, 400385334864954], [18440756702122042327404, 6571163043239296942, 387468279028908230, -6090633737859946, 2008443533899610, 1538238382868158], [-13766211159870303644764, -87636816940104846245, 449422255140942185, 6303249729358053, 2338901303380209, -3823995601011141], [5889539344639265239101, 35763840988729023819, -612192359388421718, -9508241576124728, -3988107479709891, -5447111647500945], [1188855874432211427641, -20028819956140292030, 249390886230920136, 1899974314933012, -11339377884052290, 1685463963137226], [-1509837912354887062590, 122612267456979302937, 758290868513991306, 27624347674391772, 7167355518177391, 4085489440010821], [-54256423639693194626283, 256013649783663689952, 233009105257128106, 8315636050942, 7180996506549624, 439120085550984], [-36871715734864269011118, 150197179603246702253, -684026757547039144, -16889766705025138, 265261276715075, 1934109056521969], [-35666811654253798671791, -146972270034818259697, -108424437545501810, -17480596624148628, 8716414785901353, -2507192154500589], [12714623052940042413504, -76462869008840180247, -407364969214257864, 5276604628087878, 3179542983471463, -304881678780851], [27765195572257494796512, 261347993249458437979, -663782479534674732, -28649452107091098, 10962677820842885, -2442236513865625], [-28872301258665473905506, -193697743877434391060, 998227720253535948, 20957891457461004, -3155437992269148, 2405356713112332], [-56475229756741157064252, -362401631704158436516, 332618375692163930, -27321480724352618, -1378564742128644, -422810605567116], [-55000628141866989431206, -27986952294027112444, 395968197556925216, -22577355584440040, -6927043281312708, 488690385907860], [10509005256560563572906, -59236536558877147590, -264521916672481696, 31566601735275884, 9510749827183334, -2028158768088830], [-16272916463013662181798, 3152737781409668173, -376392849022379894, -19484884418317484, 2446801013097019, -9687624264383575], [-92136041604648993396348, 510669546699372761287, 605980992086728698, -8475632433519504, 580212732683681, -3755005909222165], [-1174762535706760400186, -229811847542768526664, -619528747155554594, 25266446937377706, 6158192769260496, 2663040342975120], [109141590750745353364964, -418114468080094326198, -850624203656514466, 8400248592904454, -3320805561296418, -3075524380786230], [91516038015441161278260, -69907804055999426636, 938599377108505358, -11383810531066686, -11142051369386796, 1001108346168636], [-166894540058684687890356, -40358648706638553524, -304454568467033640, -12453279088109904, -12560366086867564, 639710140051676], [4272686449013734731996, -377806610519486109503, 3145573622465503004, -34479448419758398, -26168973316386689, 772633635688341], [-8009180711112648791254, -69729141413306051258, 232641190017317169, -43399026000412937, -5095533095654922, 7022123827983378], [1555872584905715402532, -294618388442836579663, 288184404987839580, -17330200030557966, 10118640102625071, 9731363890585461], [24682052588484814967940, -626667070257491530702, 775330073749034636, -26443504011641440, 27567208237145598, 5786399041106666], [62002569574180081718723, 227011876593634262965, 794895521524200096, -6373056110173130, 7402244392487259, -5005885353153255], [30281127268202442641995, 664566119706517222630, -167654770481430066, -2178133670053730, 7325776337217858, 5161833904344534], [152895108598837821188208, -117421441364125340402, 1188772725955077014, -30864275759376346, -8377135978776966, 3072150161199230], [-4816382773640491489300, -654141452566210033658, -1147751666765901133, 50450385040799613, 1782466407251118, 9943593455092698], [3640252106502674001456, -246551352351880697576, 2027620473475710988, 10095087450157012, 9928619870063864, -8629791787418808], [-137062812067857246426372, 724851986072227215786, 844654520408214258, -71165954213861598, -7002417597152658, -2682786735670758], [16949846749758520094852, 8664995468571687364, 2021510063378430090, 42038140238124886, -45339480958358700, 3386770646876604], [-62534825422720766995404, 874520365852200600980, 213024907258696699, 5152248017497113, 34489411540312608, 7976702671865856], [269461739742597411743970, 579873649315897178961, -2636355364536256758, -4997670855196356, 25823967015907671, -5317407584586867], [74610553527886699045470, -428655412380268272511, 4589963392333873868, 59395598246105234, 11113593588338047, -8662018608199659], [8941806836740836701916, 1041812047863453851281, 4538857174203302960, -82525477264364866, -39716042844013793, 7390098962341269], [63011649761937612842478, -351528909266226873717, -2664689938103304115, 7081499292870065, 7015517153367345, -382512212366085], [27494835858298983499346, 276274218445270694594, -5458308795427826547, 55527549009223763, -31318931086853814, 8610108465203694], [13560989662153624379082, 1385812459937676535116, -1750760349061668496, 53312847907542680, -6452526862735756, -5452100429225828], [75702004577319551899590, -880315917921287152188, 2690553375488961466, 81811254413903398, -2618853849721836, -11375063423030916], [84389919180758160112530, -727397961557528604637, 3049624047395248972, -98987037557858786, -27304196537571, -15040512763749809], [258205212259607050425338, 12340951156723320569, 7504698307142144691, -41339049433598713, 12681684965568267, -17190577832900391], [-11383062926239008313290, 550876446393117057053, -12821738967950784054, -38259916753354620, -24389718088819061, 11021349223996201], [-193162609071136739735400, -929506401140729911408, -139538890204318022, -72118825901670578, 74384237635523464, -14920361047945864], [80944243894523622027720, 698072813740382521796, 9614481261164603521, 123744385021436331, -6246049571674344, 822224480773032], [-3578678144559591636456, 575500126511006099725, -5248388331263438268, -145496975939141262, 7139650860694259, -22454811023653087], [-73777707695274771434806, 550809933623169818169, -1351369270819965733, -20683771537180033, 2010642963633963, 1083134525423481], [-52060568017353019941240, -1219663522508793605070, 2426425248165458888, 192300802161045812, -9408227582825010, 6813496197627642], [73538888775317955935276, 428740361036698627090, 9694618752977183907, -54116340677775371, -21185048238399198, -5716674559554282], [296980741852701883642794, 489652282169721002440, 7730655746169547148, 19836796888662548, -17707717727426680, 19830412445928856], [-519002103299381927519168, 1671931952825134990, -6601068008409335328, -120257266442319548, -40738959783434286, 8240167690351974], [279473685391517055252900, -417583288714498190384, -1930924076042914972, -70266827594654260, -7272184935383264, 33554705839136352], [129883429966935705156520, -2955145343197751653608, -2773174446915504326, -104774789589674690, -33501570681276288, 9734696503229664], [163628775965446628685744, 899507988047697548297, -2017343394394605970, -20173340518960120, 92160621610200751, -1111369973755035], [31045621036754326216026, 929500706861530714008, 17644489157152705408, 77284113271338832, -30771439708619288, -8414242715572744], [-189262894748856472867122, 2663633294493213954105, 2346316743511323408, -58065006362967474, -64855935699982857, 24131116056392157], [129148067852405037531084, -660031579703031158319, 12664643358836902492, -60908287442319854, 11102541463656655, 21379685438630069], [-240230369489833686648989, -1077980592051173264965, -1363427427234672020, -184716351614391858, -7230527932399227, -47826199430312121], [-220706127334292727489432, -1311231143424480590176, 14413952976272142553, -82392982634166405, -12407521018351716, -27803272188293676], [-132927121597913036661170, -1526170289081860298893, -7723535593180786553, -5146175638464081, 12735295568181153, 46306659639757707], [644397308377432941842862, 191249345769357683976, 3574308966928383548, -102138783688976092, -59303329248058744, -21898970807281256], [-627254529257378280136188, -338227472968124865190, -15155553156103614018, 131867938096833318, 113340567754205582, 6621601574542394], [-183175167482104640211482, -510085868401729865134, -5864839077567460941, 149350713541438853, -70599825106306974, 16503634587454902], [-429840259854962906956188, 3427390710167403313021, 11121748433575010400, -186388558948680378, -41611214048021805, 3900770268723297], [-421652908064319873514717, 600227759525846997717, 6309555960599296824, -155663709821258370, 27655442431396443, -28127453014767591], [313710393360156335515728, 289440945575704714906, 14833088925757490366, 137301228408393638, 81003602848756302, 3327057098917370], [-389559579050823613755888, 2064310076268191879482, -18170049751443015914, 159216006121625678, -5015755134996210, -16306285710358566], [-81478623578661509688126, 116408145147365040923, 11316654070170553462, 413901134540009356, 33563840296563261, -5110824548982353], [482307564599570168682504, 2532630116868698941842, -17380637610532336768, 38095555430910236, 61259794588301966, -28947146934670790], [159092554806618451465723, 1151474272357204879324, 10086382585857048850, 137811677987075006, 68572583171464860, -50213777178928428], [1070002840435169835117096, -368446894181626675979, 5922856029814978432, 119748483075412966, 30319855029783739, 43331527572863369], [-187808449706114605262916, -555977996092464812968, -14635354615592587496, 52373959883991352, -16707085874843128, -29234545638922248], [-389637099080376473995608, 1974445483800697224355, 1631151877408260371, -366467366301558669, 33561941184671553, 11461797248387499], [394933364258234128120552, -1530995278089489640838, 30118027573520931672, -139117501910916524, 80801156729491398, -11404853283859038], [489126789705556718459136, 2508818994337506930931, 16992621183067558746, -213402892935183528, -103999519255428619, 31638978638701415], [-876563025917818256110862, 1842903144824734619224, -7933939366935609744, -332438103175726496, -118665055749063960, 5124066832920888], [-404981581629335482918680, -557543743139263469486, 2568517840279887151, -63173245974923239, -40850442131315022, 36113943764947014], [472173605779108672408560, 4777488901998327690161, -17052515991758944332, -56000767613930694, -75265232302302385, -17763749886909163], [259529175104308523911220, -3458030250689057338390, 2291190781665874398, -247691508032960506, 32678900893825470, 70889103056728746], [229459230710674837714172, 1292766601628882609249, -7995526883744112853, 34258833546966175, 18321664484827971, 38945664521106561], [-32706014093368590250278, -6278048015523541504136, -15719739417836042820, 368388753615585444, 92310944725575896, -37138144247039512], [-392291057721252015077940, 2149126267879500243758, -21317920782254732200, 596009886188196268, 142325012071929042, 274952065296294], [775218027186225955518288, 120538045783771304416, 12427841234487381354, 138331370720137950, 186793309723209144, -67954234846452312], [590249947119645611868612, 1360803827656511770982, -13493475021979900688, -109502760689416508, -116549395827135686, 27245749792151390], [-610637346526023230123684, -3142958648323097494752, 11832122975547116808, -472882937769984552, 65713868631896256, -14067779641546176], [1447207862057266597352148, 5083449372625493732236, -25012063613352883110, -211485874830418122, 108501464704451020, -88601540802436700], [-418417089988443012370120, -1636003395586604206113, -26608716308766015015, -602505122942825427, -162187498268513811, -58999877043222897], [-1349673680052075566341428, -1286196091051451277466, -16700078232253169720, -446783243081094900, 60072579377277786, 60077179622502270], [1458063866347575020262880, -1340715756759446905638, 34507731491662621338, -63962930834746854, 26455077251453790, 29771482880034954], [400043377381187131947040, 2478289116603963737512, -12910840059846547643, 36868685011945775, -276636785248234908, 67117248301498092], [-2005638748244481304908391, -4777891121155584391622, 9365057221982224178, 213528325341025506, 50520582642649374, 11172311140204170], [-902021064639948054457640, -3514897240538530245760, 4998785055077954091, -185175119868746287, -150219143731409868, 28671558277800924], [480714387185213704439130, -9793586400759146208172, -2664778522404895832, -723064284090419600, -154820668969258612, 24959900991882852], [600840662916617952361720, -47331271281647510849, 5787998344195760833, 105422860469181797, 92143435088622573, -77972247401694129], [6849610380567163893637, 3355044759288665362104, 4890492350239912810, -509448235398873074, 137986210321692192, -31301907998383872], [-607453145659308119605080, -486728510604496124458, -158194229140530428, -140599168405093760, -49474950250559686, -22841842298068866], [-988873065549487810153386, 6876478271715782605511, -8359161601588343768, -144021847124895302, -98245192275580695, 73992460120721443], [-810986586852716702951730, 2156021079965628163770, 28381588596400865174, 62558378568781358, 38021466364568910, -4213504594583622], [-771654955107036820762002, 8454004265466649661937, 50494078478469007074, -73940732747827404, 153658689539379895, -42262015587939491], [697133500379949290902606, 6613551618390150451811, 28370377785297571447, -258094023138810465, -359716204281739023, 7520151948628923], [2242808228477050241854961, -1808154548223501876303, 1206142818151115174, 80656040772863024, -230453982821362617, -63102503813788611], [866613908090236309466472, -3007631966715931517302, 11344781390018430918, 364547795468184030, 273312450788339518, -83879758158305462], [-440569618908592829267409, -1057645311523922523600, -3170885781575599664, 1051372459255948048, 11881306078090128, 65166965142232752], [-1332061999006449340505916, 2513612703401629649197, -55051745475642371946, 73922676706561752, 292868058808446827, -55125312083407399], [-2114804111608639006056568, 12890096803765706469762, 67680609877905737580, -370782505952021472, -234859625414898642, 140378419580559930], [-2990777313323857788610332, -2771367596931624118753, -15873506189865230198, -139219842182025056, -66343281841626391, 39392679601139187], [3460983277022532035293332, -8605281022514346984140, -6668182561068609498, 576037227165711210, 32537949152698036, 31891541776395004], [196121898041587890403128, 6863489312263222164474, 9819904848547253064, 255649227935667684, 205477194124438534, 71514862297545634], [1985364140890270639493976, 1492768352305126241778, 65270333884035279200, 156066917023410332, 245587148236527086, 190958942619385594], [-850619970264784179969432, 17541868681902510742, -81617589758639596884, 584894092921230360, -340482465861385702, -128207296738977346], [-119805207645543184927298, 2353863332175158490197, 57686548808000215941, -1260742427729684635, 123288253537594599, -80880533354311155], [-382066344054959660496192, 5351159462480913499559, 114485709365360630270, 967072623034041980, -21370277643958479, -48992721782805733], [-2072858867405063313833350, -2236408895275102027098, -20205397497554264133, 292485294063250101, -218455274917311570, -217481978213510022], [-251555238996285549080484, -9169510916646597851655, 4793321978645771790, 423094072621127688, 364197058916011839, 216074360479598613], [-3837666447448199628830676, 80783522712171073389, -45813658548001828392, -601346583369452754, -119087811725014845, 94450158177111441], [2277059911181484571795900, -729683250832376493684, -47419060599022491048, 1243124107196588784, 589453714158638292, -105918618809029284], [-1264060292261537852756110, 15759518301345276082468, -87758443927703379232, 986105829739865688, -104315507978557284, 104260808619373428], [-482857615151470783939872, -2661378629405734295208, 89958828412871321452, -676122432158123660, -314454561373350600, -131326102562028920], [-1040389742512862392599846, -2898912873853910692256, -292326259090742077, 460943244490439673, -96797637073247436, -343375593381362052], [-5047599961137749192202, 4560752839525980948134, 3287753589195491252, 537300566191315760, 462481716334974762, -178471627094860786], [-3435869309560910611020396, 4450084340313427767240, 34525859132524968944, -352974128204001088, 749688183060185592, 99814456686262824], [-670398113450425719241487, -10796644999935377433112, -23897606647130680566, -620514810026756338, 965037903068440944, 70754992668910512], [1602993545709321620692128, -1225248245532309180478, 15392262440955426376, 1599939475399330708, -329913569907628738, 165570889537914954], [3144702707958905466129110, 18251088799012240071421, -5326523329583735583, -517351489989196247, 352694408835120975, 202454502546315141], [-2965620619086404460246006, -2608076952707358684085, 32664172222697560888, 1642198090662109282, -367056502992989851, -265541213352065481], [3790328281149870636459200, 9262818063942722741350, 34058117543376986990, -994261231461081474, -383137578222249150, -290411480927555370], [733748754485068282779210, -7701268593017465266587, -121924935646815318882, -693009167673698880, -454246094409953517, -235382084662372719], [5447810722139530151305380, -17981149387213070082402, -23523322345609658956, -112552090482817024, 143326262721282098, -2087417973914714], [3685172140100225097679560, -5511265533369955748768, -147604399802488540396, 901844088557249564, -273773479387436144, -12238033588580592], [480015114006987425197705, 14123793281560008611041, 127533393621375694176, 2736578451382725214, 460450367323950447, 142190861627365749], [2154308557910254682421750, 8119977133627773287725, -115757063583291221706, 907712271873792504, 408665495760810603, -64070038066604583], [5310818239620785274945315, 1119510415836180749860, -46949586976873581322, -3002880208132283046, 292941905166784836, 185063625380262348], [-3543197559384657516393180, -17264460361945866555151, 20924205660332202536, 301698952694622998, 139037092409532735, -178504453185045211], [2015000017233727144777104, 46830931431391448527044, -86179550171580949052, 963220274288453284, 460045553104798252, 124875072603046724], [-482542790290961935712599, 19930783062085833211906, -72401418566321159350, -1117306480320890214, -430003893820344714, 432399182757020946], [6662869003011834803642982, 38981825971589391236981, -80191256824394453038, 133533282577773740, 488897647714700307, 88939109241060161], [3266641110541824393246656, -14777417294368865596614, 99247374308398060980, 272122607793190056, 536012166474512406, 330647353592727186], [-2999068039670310878828057, 14369496933660005807774, -78711508078310008134, -191512316657207374, 719943280704952794, -109900620254861730], [5739284336538604292380416, -13722487940090110125333, -52120337633038571158, -146432202367797640, 522868801306067709, -277312817195968225], [-3996567592062653328105156, -7564629308102651578094, 89820598125586964935, 1338085331987718689, 582701049271268370, 328812289059976038], [2450587987866768184720002, 14114281868036316988198, -24939747827648446952, 607454826718307164, 1365338710901764122, -316567500411573986], [-2563760040746007939026724, 13559666760616895069512, -133604676263389932994, -274386368683487574, -742235591210315328, -289649762263287648], [86919916679062483413641, 25735796195491578352295, 56106074385480471828, -3343842732563082898, -812417224747520583, -65194362412139133], [-4226134718950991979814635, 20387569226612292918165, -141036453883944975530, 1577798308976028280, -1457002575314153757, -211792576705657551], [13377187140930287819418990, 6149139691762751509549, 102595374580721194690, -1847565887974511780, -89207017069432389, -119556539678050487], [1159456094057459834631084, 9525621868865726072209, -21440501352236873826, 2113219762717862664, 493997261114286055, -121341206382647219], [5023831225660402087159414, 14914565472077731414061, 135418025794957698049, 2679216255150426537, 1110951700265658015, -182023442754824907], [-2948631862655648362886388, -21326392859632968213458, -133178210837353124974, -2175942025796443462, 704510775981491754, -80944356508722898], [-15508216897666919402145940, -10001261062479500432022, 7502999694822051285, 514857384572115195, 322424082691975746, 445990542619099446], [-6879230054439786389712060, 7516793754302016582501, 18852077659991781136, 162155839745417062, 418214101834583147, 831371221376529225], [360427700953123150747481, 38426276437986856125571, -93163388807770998492, 484158333565082278, 655505075916456669, -380836070484300081], [9269308696802947765236756, -35075334041982793244880, -29188959727433456264, -1760315797921110008, -222733020516155920, -124782170357177520], [11300810201476559125829066, -6482326438155560900255, 234196512647442006855, -199164256937531405, 120212108292734163, -412252187432769423], [4750585580989611648138240, 15160965372080624348059, 180493189683342597010, 2032646128166872576, -1642461843235510643, -482877169837079809], [5054208916589146826723861, 28130325760981442699736, -6721764738243444576, 1468485636632429424, -458214376207358808, 728249102952278328], [1850935233971857723195154, 1269448568057613069654, -23063068196445140494, -4199198221113331318, 1021811334091025922, 83025593019512694], [2172044869179051754361298, -44698010230772537162767, -39719934442502611127, -2467733149778869959, -184747138255981701, -469781052645527127], [-90679348882386107643252, 34309885111712139433387, -147410450053541002302, -1106103546887438544, 218606436039755325, 323321604633569103], [6783450011107148057567340, -6733931865434215163493, 112292017321613241628, 2941730005018587310, -583708129474232315, -349375077584113321], [7935289524564922727617906, -5599430831613854823412, 97864393366354641229, 1320836601672937311, -1029797289982543392, -944096108165393760], [4028628473805998212019856, -89873386264911299295587, 78578260928986834724, 1220591036414675714, 921038353727891715, -253728671935215775], [-6824944154547004302483882, -38276846940757445713922, -9724489689895630916, -1246153177485100616, 440245544340525426, 229129445984879686], [1133250797025745929095774, 34345031542675140742295, -239610295835561515179, -912242391421493263, -813504911266148283, 48503378977143831], [4540198133831140378734459, 17250016574279643369429, -241940221923837916112, -924022038121171610, -422530646357877381, 180613711864089081], [-4623408050853289523731842, -23919176209942929771147, -10778916622310299096, 5701221951377494430, 1614164427723057179, 801744733089353257], [2806706296590302333028120, -20613844108183977128514, -344501107692079091496, 2582663937787293420, -496041416513406206, 562264047555697174], [2706670750099996820271931, -39873214576496372069095, -5695500775520982794, -1099704232267488048, -2653291147750263009, 68194822879457541], [-3162815133665483735979244, -51814716765974436667350, 349930974920907240566, -5278150814965192306, -1315371498223071330, 115269339648235914], [-6645737184584832252611328, 3934457083819474555629, -310817383910826592304, -339144234948522938, 642076546255316931, -1155606956121609791], [-7288702085671477817741646, -47175414932581954816934, 50287195499349533359, -669872671348131607, -176313032522046486, -259490659264059762], [7092734831442353605722232, 24646319548265672345141, 170779713975983562517, -1754706477975989355, 322092255245900103, 703567906181391213], [-7345797462984524409890778, -32392322675199518652802, -208107662221533036448, -2010956203359555580, -176935901525409246, -24325064124539146], [-8248986568025221425817806, 62809886747738454391445, 284323292294948082368, -2780641706935170682, 2279193917563830107, -446203660478149943], [-13856699926089445103165388, 17878886344066903272051, -110349628241639153140, 1319981775266156606, 100276248213407693, -1330680310402157729], [1006435406613311917835670, -74794588228453761986117, 46960795611383614326, 2922093461064679308, 1390639945025246237, 626478085339624079], [-12493099732069913131219662, 39292664307548948701155, -278619767254305300322, -1260400282497741916, -2085420848974014539, -573977614931291001], [1222253958606944510329638, 42283102312636091037801, 157764271933053625153, 4562810387762392945, -96176809982813661, -1219328504423403039], [-6149382332591859983137662, -3174179288015962175282, 273649889654822552912, -4102261238787905260, 1076384414037816530, -757042340217860378], [-12232839852113040626432070, 26104041613821942650387, 35563101288126735098, 742961960190180632, -739634939295272043, 1271676748585227431], [-858778299870103988533500, 67056730564787369901390, -16708591521296661448, -162693257050322740, 3826866936966852786, -1449759371673884026], [-9815020595247309400663196, 74878948885796087878806, 86378873315138648412, -446021625809299992, 3354868212052945626, -1157930355024492354], [14522027583111312399427263, -109382152151360035545320, 100209822444963441382, 3593056532876328578, 1881250662243100752, 332284174034771088], [-11486386716571626116024028, -22665422843114213306944, 160910003090352555620, 6296635678394380940, 425143149087892848, -897887690383962640], [-38563313199853688093242, -42167127378757624291592, -78352284645332084026, 908162409982286754, -3319026686755190928, -213704866916810064], [-5506513224865114855866325, -135060431918262840602718, -215687629144320418008, -2186709480489699276, -990519476994609570, 1576871744673856554], [-16235916697661215270350852, 20693595299871693212380, -670356551727162805368, 8083781925090163296, -1215779047063368508, -571875540171294676], [14306864655222095275014511, -101088732415221322897919, -331586046067425572708, -5161355131402168174, -558861010513208865, 103188260895550533], [789699397163739615747990, -76525088838234224714273, 198177995872730555222, 733484547826606580, 2334257870099716569, -306433771464496141], [33676827561630749750416320, 47613398177889153149334, 106950064091196533656, 6519026979687280828, -842758914830921174, 965411403549459086], [-7275746947936386934603538, 78183473469160121962774, -305017613226943238066, 671461771231288670, 1925577527777805906, 32157282447689958], [-8566382278233911994866664, 1591103398259047079259, -540634690055651322467, -24974240862355007, 1029957025691994273, 901457451222836427], [-5006940986179216812759090, 4186511536655693801381, -705492680452300841524, 2436859209569345210, -3133788567490472069, -806248094601033639], [-10067274265645167257750268, 89833823933950167263262, 279140531908015382714, -2550576072435706126, 4757941885426137050, 240595219538613598], [13044494326984746438083587, 28801140923484003793372, 369686905019315088486, 9758778255836365114, -1402747930223659188, 1604575382405724324], [13486163389215527835480504, -5968768580980649170612, 134858774925082769092, 3683258295623538676, 4515281179701927140, -578077026111258228], [-21391751842507159749458799, -173161447889058758371394, 248047293505606607758, -2103396425024612242, -1081569231987474582, -1576859663367467442], [5740179484911637695528216, 100426558941765007396164, 888257821348603410630, 3179272225468441290, -3752426110415479708, -615871766053181140], [-20921236828473656306023230, 50015241416833721512443, -120804009362624273314, -6454845257058820444, -2612717981770871299, 2069916048101327887], [-2306328503910497006564934, -100026574890802817356110, 134759582750223486442, 1689577730750229754, -1769421838359008250, -1672048439310505950], [-26758862118237542057287296, 29220205160604263096517, 57494106029703655490, -2454152529231235300, -1642095924783874173, -166463553507265327], [-14263674375090567190535744, -146449927589991221489732, 272039046250563320788, -3232769467234596412, 628357159950828084, -356107811828774148], [-28363576061344263600647352, -26562879804371131427664, -224864759655146327714, -6499994933714613542, -2654812127907439464, -697227162286893752], [-22037181960318171742793062, -37529864466987286207934, -609760634537915280813, 8332540626840120517, 2941938627681312882, 237906120060834534], [13140728261891234484685216, -8934611365883498122426, 280564607743732514814, -6270539075221004050, 1083908237342779170, -212347659860434314], [-30402538976373509737226980, -137312751765436859842714, 55592358012417411068, -2061021980959631576, -1094030936509965174, 1215397628322905934], [-22560657221593526858738658, -84650234480561576784461, 409910515274646779358, 13044734076387760356, -721613992639789531, 90591561305091191], [11584941305479393899012691, -15949039331777511926322, -392001819363705961418, 1603626161354182918, -115555934992089798, -2081765658220608258], [315823396273743276970344, 16947532825036020658305, 1373554288450942729130, -7092391885901086804, -1703102007183617657, 126121969305937485], [5306757895000262704484874, -83977975676999237957001, 696264594148447897736, 5933428926520676618, 2325441208129490649, -2535689573784976189], [48135335038809839410579471, 164429059122502616388049, -582849758186499735942, 1631632188741559468, -226899790968205737, -89763761857382163], [-14627599887886103586074928, -74564106271073961525246, -819252674880605451442, -929515944099844666, 4226974348685497254, -1641489879593738494], [44155414405336691799703765, 47672086500151848017304, -588624450381866402982, 6713075584296985758, 54337177306143360, -534867479151893856], [-42691999740337384320116104, 6960736081849038601148, -651179044643278628895, 5431903509154634843, 191237795605744416, -751527520244690112], [-27637174427167902998850132, -47878064234279162563725, 223476082177426370798, -2492217966018214300, -1181727799603684411, 1882900632824552359], [-10121468180787810838464381, -63505216331098460490675, 423346321604973304952, 2554726267232005454, -6503614994678727069, 1071195768978108849], [-195774819869242518976128, 7319182073805476035882, 294893275126790141792, 6877655766140509484, -2879435399001927626, 1901149799587166994], [-17409411296360647572937524, -159577780161949403034144, 67847455220485641254, -9029662114909123054, -11003710977942551352, 1089539043949428696], [6911921203262301116116320, 111652742564094291991199, -191720735865673599046, 797340128810555696, 4093304201196705705, -2575444158576350029], [-2521126636377024163720200, 149954809919712364225936, -589568894407665149495, 14743758162858728939, 171160724110444524, -746837727465957372], [-19488512947989952019162280, 36202546017381575101181, 41499734026348691334, 4548923674719010776, -4263373629728650885, -2270928141769768807], [-12489692830001942669150376, 8191730926116430066101, 841863928573371428878, 21712790971099604848, 197816958574112259, 159364779107186209], [-6501571530122222981199954, 39779797183285520528978, 1049947933849710750230, 6558562108401507646, -9228978744732411210, 1422908059690770930], [-15462649166511320963616218, 180319608626227430435829, 532051750032435720339, 10772400951486249711, 11911757584356484047, 1274296984442327493], [-24393684978081072776757456, 18527118560786935729059, -824762210399632307362, 741384923273191220, -1807147619755245419, 3372294013773689079], [26777153084790802498879337, 142233912850808526935539, -868181461826938805218, -5038603636565863980, -2944467782465484987, -1238528389769772345], [-29106196332168631119898452, 197694849386880662677570, 835340621507825822740, 16230084995411654680, -2838797819196902706, -1591734314222937254], [12630690827246375738864357, -18436930441059906697410, 612261157169900787080, -7512531885745025572, 687505527580386690, 836465500426332726], [-25374114685781714390977908, 21161525393879695383348, 1921927473918728544, -6041542401844542312, 662236994153630028, 3534606139052592996], [-66888671483940191249097486, 170369272611637165374632, -646764126820505620916, 8046092197435570996, -7778690852102109464, -1214937913374870184], [-27341121370489364375983601, 60320439678048424145979, 314376638702596980886, -13296490411424824724, 2999057666352098589, 537929801797500495], [48015468093051391571564917, 94224240408568958346288, -960878639587784609586, -13297201174810853046, 1240819972839795096, -327875257573226136], [31928303589477602467011360, -33416467594436614346412, 302653434270925408692, 19202780985127238676, -1381924229296110500, 1218627297876778516], [-33294902417679238251588000, 72034449890830214092390, -348691585483024613698, -17642865045115079698, -2116114918569101310, 1584538402176612566], [24558610601520912178223988, 108939048895830592827010, 1487522983971926943937, 825167678054563535, -4411498956714272646, -2504174633508108258], [-67651016216803124061538296, -260465580709265773850517, 654819648519970606422, 9177220710034428396, -6087655814352214227, 1141082476760588127], [-16245249730274976262590750, -116782930472108199961853, -545586158550004189600, 27495876962878631402, -4634808051105352051, -1854183618016862609], [33680114522503251330746508, 45867825257074203437378, 211819403273906851792, -690060421128164564, -1074623550434185826, -3226033877441065366], [-34746810898242267407797008, -140763334053586945231265, -271206961816256257433, 15094382221093821815, -5298823135101149451, -2236246834634442009], [-29426522172406876602660672, -278924813004164244321306, 621399940419394129350, -9210367635869582970, 15122505339056746338, 644778510302679030], [68633697135095140729601118, 49020826625420099344446, 334140760553689762496, 15026371970691563108, 5904704418050639970, 1962855686723125238], [-621151221516710916853862, -102012883142949617903932, 543838132513896367968, 4465115127823399640, 7470673543895147388, 6456789881119196244], [41905056306890104875977664, 205311882866950807187057, 7080460716218587890, 430800759611163780, -1500963337116572361, -3813409200904929603], [-7860896736920780955796074, -142717307161805019059681, -233393295969732595992, -38875739795273882598, -864337614978557775, 94901668234683723], [70181253138662794230800412, 177678720925362702241847, -1970912578441517798978, 15152470260004561228, -5228991969550735615, 1948703554566427131], [-33945086219996182055943319, 64044422524594218892719, 725911518982176833766, -6543957131383281228, -9987426151653546711, 4644154927778592339], [44575186827743611188004698, 71822623280608824876335, -1717837098445782810498, -15947570969485405716, 8634465436290735401, -4099000155178248445]]
